@@ -15,12 +15,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "core_debug.h"
 
-#ifdef Q_OS_LINUX
+#if defined(__GNU_LIBRARY__)
 #include <execinfo.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -28,10 +28,10 @@
 
 void logBacktrace()
 {
-#ifdef Q_OS_LINUX
-    void *array[32];
+#if defined(__GNU_LIBRARY__)
+    void* array[32];
     size_t size = backtrace (array, 32);
-    char **strings = backtrace_symbols (array, size);
+    char** strings = backtrace_symbols (array, size);
     backtrace_symbols_fd(array, size, STDERR_FILENO);
     free (strings);
 #endif
