@@ -22,7 +22,6 @@
 #ifndef TELEPHONYPLUGIN_H
 #define TELEPHONYPLUGIN_H
 
-#include <QLoggingCategory>
 #include <QPointer>
 
 #include <KNotification>
@@ -45,8 +44,6 @@
 
 #define PACKET_TYPE_TELEPHONY_REQUEST_MUTE QStringLiteral("kdeconnect.telephony.request_mute")
 
-Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_TELEPHONY)
-
 class TelephonyPlugin
     : public KdeConnectPlugin
 {
